Public demo instances to explore in the UI or load using the CLI via `lamin load owner/instance`: - [lamin.ai/laminlabs/lamindata](https://lamin.ai/laminlabs/lamindata) - A generic demo instance with various data types - [lamin.ai/laminlabs/cellxgene](https://lamin.ai/laminlabs/cellxgene) - An instance with CELLxGENE data ([guide](docs:cellxgene)) LaminHub neither hosts data nor metadata, but connects to distributed storage locations & databases through LaminDB.

See validated data artifacts in context of ontologies & experimental metadata.

Query & search.

See scripts, notebooks & pipelines with their inputs & outputs.

Track pipelines, notebooks & UI transforms in one registry.

See parents and children of transforms.